/*
############################################################################
###################                                      ###################
###################          ABB Automation Products     ###################
###################                                      ###################
###################               abbdef48.h             ###################
###################                                      ###################
###################  cmd48: define lables and bits       ###################
###################                                      ###################
############################################################################

This software may not be used, either directly or by reference,
such that the software provides functionality to an end customer,
unless explicitly lisenced by ABB Automation Products GmbH.

############################################################################

Author:         ABB Automation Products GmbH
                37070 Goettingen
                Germany
                Fax: 0551/905720

****************************************************************************
                Revision:						0.0.1
                
Date:           10.March 2003

*/

/*
definition two status response bytes

first status byte (communication status or (notification, warning or error))
=================
0x80	1 										- this bit must always be set to indicate 
															a communication error
			0 										- this bit must always be reset to indicate 
															a command response summary information
			response code
					 0									no command specific errors
					 2									invalid selection
					 3									passed paramter too large
					 4									passed paramter too small
					 5									too few data bytes received
					 7									in write protect mode
					16	0x10						access restricted
					32	0x20						busy
					64	0x40						command not implemented

0x40	vertical parity error - the parity of one or more bytes received 
															by the device was not odd

0x20	overrun error 				- at least one byte of the data in the 
															receive buffer of the UART was overwritten 
															before it was read (i.e. the slave did not 
															process incoming byte fast enough)
											
0x10	framing error 				- the stop bit of one or more bytes received 
															by the device did not match the check byte 
															at the end of the message.

0x08	longitudinal error 		- the longitudinal parity calculated by the 
															device did not match the check byte at the 
															end of the message

0x04	reserved 							- set to zero

0x02	buffer overflow 			- the message was too long for the receive 
															buffer of the device 
															
0x01	reserved 							- set to zero


second status byte (field device status)
==================
0x80	device malfunction		- the device detected a serious error or 
															failure that compromises device operation

0x40	configuration changed - an operation was performed that changed 
															the device's configuration

0x20	cold start		 				- a power failure or device reset has 
															occurred
											
0x10	more status available	- more status information is available 
															via command 48read additional status 
															information

0x08	loop current fixed		- the loop current is being held at a 
															fixed value and is not responding to 
															process variations

0x04	loop current saturated	- the loop current has reached its upper 
																or lower endpoint limit and an cannot 
																increase or decrease any further

0x02	non-primary var. out of limits 	-	a device variable not mapped 
																				to the pv is beyond its operating 
																				limits

0x01	primary var. out of limits 			- the pv is beyond its operating 
																				limits
*/

/*    Define cmd 48 bytes  ERROR xmtr_spec_stat _0, _1				*/
                          
#define		label_xmtr_specific_status_0                        \
                "|en|Errors 1"																\
          			"|de|Fehler 1"
                          
#define		label_xmtr_specific_status_1                        \
                "|en|Errors 2"																\
          			"|de|Fehler 2"
                          
#define xmtr_status_00x01			                                \
            { 0x01,  "|en|empty pipe"													\
										 "|de|Rohr leer" ,												\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_00x02			                                \
            { 0x02,  "|en|A/D-converter"											\
            				 "|de|A/D-Wandler"    ,										\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_00x04			                                \
            { 0x04,  "|en|Driver"															\
										 "|de|Treiber" ,													\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_00x08			                                \
            { 0x08,  "|en|Flow > 105%"												\
										 "|de|Durchfluss>105%" ,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_00x10			                                \
            { 0x10,  "|en|Zero return"												\
										 "|de|ext.Ausgangsabsch." ,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_00x20			                                \
            { 0x20,  "|en|Database"														\
										 "|de|Datenbasis" 	,											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_00x40			                                \
            { 0x40,  "|en|Totalizer"													\
										 "|de|Zaehler" 	, 											  \
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_00x80			                                \
            { 0x80,  "|en|high Alarm"													\
										 "|de|Max.Alarm" 	,												\
                    HARDWARE & CORRECTABLE & DETAIL }

#define xmtr_status_01x01			                                \
            { 0x01,  "|en|low Alarm"													\
										 "|de|Min.Alarm" ,												\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_01x02			                                \
            { 0x02,  "|en|ext.Database"												\
            				 "|de|ext.Datenbasis"   ,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_01x04			                                \
            { 0x04,  "|en|ext.FRAM"														\
										 "|de|ext.FRAM" ,													\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_01x08			                                \
            { 0x08,  "|en|old primary"												\
										 "|de|Alter Aufnehmer" ,									\
                    HARDWARE & CORRECTABLE & DETAIL }


/*    Define cmd 48 bytes  ERROR MEMORY xmtr_spec_stat _12, _13		*/
                          
#define		label_xmtr_specific_status_12                       \
                "|en|Error Memory 1"													\
          			"|de|Error Memory 1"
                          
#define		label_xmtr_specific_status_13                       \
                "|en|Error Memory 2"													\
          			"|de|Error Memory 2"
                          
#define xmtr_status_20x01			                                \
            { 0x01,  "|en|M:empty pipe"												\
										 "|de|M:Rohr leer" ,											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_20x02			                                \
            { 0x02,  "|en|M:A/D-converter"										\
            				 "|de|M:A/D-Wandler"    ,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_20x04			                                \
            { 0x04,  "|en|M:Driver"														\
										 "|de|M:Treiber" ,												\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_20x08			                                \
            { 0x08,  "|en|M:Flow > 105%"											\
										 "|de|M:Durchfluss>105%" ,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_20x10			                                \
            { 0x10,  "|en|M:Zero return"											\
										 "|de|M:ext.Ausg.absch." ,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_20x20			                                \
            { 0x20,  "|en|M:Database"													\
										 "|de|M:Datenbasis" 	,										\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_20x40			                                \
            { 0x40,  "|en|M:Totalizer"												\
										 "|de|M:Zaehler" 	, 											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_20x80			                                \
            { 0x80,  "|en|M:high Alarm"												\
										 "|de|M:Max.Alarm" ,											\
                    HARDWARE & CORRECTABLE & DETAIL }

#define xmtr_status_21x01			                                \
            { 0x01,  "|en|M:low Alarm"												\
										 "|de|M:Min.Alarm" ,											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_21x02			                                \
            { 0x02,  "|en|M:ext.Database"											\
            				 "|de|M:ext.Datenbasis"   ,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_21x04			                                \
            { 0x04,  "|en|M:ext.FRAM"													\
										 "|de|M:ext.FRAM" ,												\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_21x08			                                \
            { 0x08,  "|en|M:old primary"											\
										 "|de|M:alter Aufnehm." ,									\
                    HARDWARE & CORRECTABLE & DETAIL }


/*    Define cmd 48 bytes  WARNINGS xmtr_spec_stat _6, _7		*/
                          
#define		label_xmtr_specific_status_6                        \
                "|en|Warnings 1"															\
          			"|de|Warnungen 1"
                          
#define		label_xmtr_specific_status_7                        \
                "|en|Warnings 2"															\
          			"|de|Warnungen 2"
                          
#define xmtr_status_14x01			                                \
            { 0x01,  "|en|ext.Total. reset"										\
										 "|de|ext.Zhler reset" ,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_14x02			                                \
            { 0x02,  "|en|Simulation"													\
            				 "|de|Simulation"    ,										\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_14x04			                                \
            { 0x04,  "|en|Test mode"													\
										 "|de|Test Modus" ,												\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_14x08			                                \
            { 0x08,  "|en|Functiontest"												\
										 "|de|Funktionstest" ,										\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_14x10			                                \
            { 0x10,  "|en|Overflow F"													\
										 "|de|berlauf V" 	,											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_14x20			                                \
            { 0x20,  "|en|Overflow R"													\
										 "|de|berlauf R" 	,											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_14x40			                                \
            { 0x40,  "|en|Overflow diff."											\
										 "|de|berlauf Diff." 	,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_14x80			                                \
            { 0x80,  "|en|reverse flow Q"											\
										 "|de|Rckfluss Q" 		,										\
                    HARDWARE & CORRECTABLE & DETAIL }

#define xmtr_status_15x01			                                \
            { 0x01,  "|en|Prim.data loaded"										\
										 "|de|Aufn.daten geladen" ,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_15x02			                                \
            { 0x02,  "|en|Update int.FRAM"										\
            				 "|de|Update int.FRAM"   ,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_15x04			                                \
            { 0x04,  "|en|Update ext.FRAM"										\
            				 "|de|Update ext.FRAM"   ,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_15x08			                                \
            { 0x08,  "|en|Poll.Addr. > 0"											\
										 "|de|Poll.Adr. > 0" ,										\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_15x10			                                \
            { 0x10,  "|en|Simulation IOUT"										\
										 "|de|Simulation IOUT" 	,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_15x20			                                \
            { 0x20,  "|en|Simulat. Pulse"											\
										 "|de|Simulat. Impuls" 	,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_15x40			                                \
            { 0x40,  "|en|autom. Adjust"											\
										 "|de|autom. Abgleich" 	,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_15x80			                                \
            { 0x80,  "|en|hold - MV"													\
										 "|de|halte - MW" ,												\
                    HARDWARE & CORRECTABLE & DETAIL }


/*    Define cmd 48 bytes  STATUS xmtr_spec_stat _4, _5		*/
                          
#define		label_xmtr_specific_status_5                        \
                "|en|Status 1"																\
          			"|de|Status 1"
                          
#define		label_xmtr_specific_status_4                        \
                "|en|Status 2"																\
          			"|de|Status 2"
                          
#define xmtr_status_05x01			                                \
            { 0x01,  "|en|Test IOUT 1"												\
										 "|de|Test IOUT 1" ,											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_05x02			                                \
            { 0x02,  "|en|Test IOUT 2"												\
										 "|de|Test IOUT 2" ,											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_05x04			                                \
            { 0x04,  "|en|Test contactoutp"										\
										 "|de|Test Schaltausg." ,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_05x08			                                \
            { 0x08,  "|en|Test Pulseoutput"										\
										 "|de|Test Impulsausg." ,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_05x10			                                \
            { 0x10,  "|en|Adjust IOUT 1"											\
										 "|de|Abgleich IOUT 1" 	,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_05x20			                                \
            { 0x20,  "|en|Adjust IOUT 2"											\
										 "|de|Abgleich IOUT 2" 	,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_05x40			                                \
            { 0x40,  "|en|Test contactinp."										\
										 "|de|Test Schalteing." 	,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_05x80			                                \
            { 0x80,  "|en|not used"														\
										 "|de|not used" 		,											\
                    HARDWARE & CORRECTABLE & DETAIL }

#define xmtr_status_04x01			                                \
            { 0x01,  "|en|Functiontest on"										\
										 "|de|Funktionstest an" ,								  \
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_04x02			                                \
            { 0x02,  "|en|Q-Simulation on"										\
										 "|de|Q-Simulation an" ,									\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_04x04			                                \
            { 0x04,  "|en|autom. Adjust"											\
            				 "|de|autom. Abgleich"   ,								\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_04x08			                                \
            { 0x08,  "|en|Error autom.Adj."										\
            				 "|de|Fehler autom.Abgl"   ,							\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_04x10			                                \
            { 0x80,  "|en|not used"														\
										 "|de|not used" 		,											\
                    HARDWARE & CORRECTABLE & DETAIL }
#define xmtr_status_04x20			                                \
            { 0x20,  "|en|Result functiont."									\
										 "|de|Ergebnis F.-Test" 	,								\
                    HARDWARE & CORRECTABLE & DETAIL }

/*
	                   "|en|1234567890123456"										\
				             "|de|1234567890123456"
*/
